@@ -8,7 +8,7 @@ censobr_env <- new.env(parent = emptyenv()) # nocov start
 
   # local cache dir
   cache_d <- paste0('censobr/data_release_', censobr_env$data_release)
-  censobr_env$cache_dir <- tools::R_user_dir(cache_d, which = 'cache')
+  censobr_env$cache_dir <- fs::path(tools::R_user_dir(cache_d, which = 'cache'))
   # gsub("\\\\", "/", censobr_env$cache_dir)
 
   ## delete any files from old data releases
