@@ -15,6 +15,8 @@
 #' @export
 #' @family Census tract data
 #' @examplesIf identical(tolower(Sys.getenv("NOT_CRAN")), "true")
+#' library(censobr)
+#'
 #' # return data as arrow Dataset
 #' df <- read_tracts(year = 2010,
 #'                   dataset = 'PessoaRenda',
@@ -69,7 +71,7 @@ read_tracts <- function(year = 2010,
                               cache = cache)
 
   # check if download worked
-  if(is.null(local_file)) { return(NULL) }
+  if(is.null(local_file)) { return(invisible(NULL)) }
 
   ### read data
   df <- arrow_open_dataset(local_file)
@@ -89,7 +91,7 @@ read_tracts <- function(year = 2010,
   ### output format
   if (isTRUE(as_data_frame)) { return( dplyr::collect(df) )
   } else {
-      return(df)
-    }
-
+    return(df)
+  }
 }
+
