@@ -1,8 +1,5 @@
 library(testthat)
 library(censobr)
 library(dplyr)
-library(arrow)
-
-data_release <- 'v0.3.0'
 
 testthat::test_check("censobr")
